==> ko-2.6.4.zip: ko/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '글꼭지 내용으로';
$GLOBALS['__l10n']['To menu'] = '메뉴로';
$GLOBALS['__l10n']['To search'] = '찾기로';
$GLOBALS['__l10n']['By'] = '글쓴이 : ';
$GLOBALS['__l10n']['by'] = ' 글쓴이 : ';
$GLOBALS['__l10n']['on'] = ' 올린 때 : ';
$GLOBALS['__l10n']['On'] = '올린 때 : ';
$GLOBALS['__l10n']['Continue reading'] = '본문으로';
$GLOBALS['__l10n']['no comment'] = '댓글 없음';
$GLOBALS['__l10n']['one comment'] = '댓글 하나';
$GLOBALS['__l10n']['%d comments'] = '댓글 %d 개';
$GLOBALS['__l10n']['no trackback'] = '글걸이 없음';
$GLOBALS['__l10n']['one trackback'] = '글걸이 1 개';
$GLOBALS['__l10n']['%d trackbacks'] = '글걸이 %d 개';
$GLOBALS['__l10n']['no attachment'] = '첨부파일 없음';
$GLOBALS['__l10n']['one attachment'] = '첨부파일 한 개';
$GLOBALS['__l10n']['%d attachments'] = '첨부파일 %d 개';
$GLOBALS['__l10n']['previous entries'] = '이전 글꼭지';
$GLOBALS['__l10n']['page'] = '페이지';
$GLOBALS['__l10n']['of'] = '의';
$GLOBALS['__l10n']['next entries'] = '다음 글꼭지';
$GLOBALS['__l10n']['Search'] = '찾기';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '<em>%1$s</em>에 대한 찾기 결과가 없습니다.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '<em>%1$s</em>에 대한 찾기 결과 : <strong>%2$s</strong> 개 찾음.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '<em>%1$s</em>에 대한 찾기 결과 : <strong>%2$s</strong> 개 찾음.';
$GLOBALS['__l10n']['Home'] = '처음으로';
$GLOBALS['__l10n']['All keywords'] = '모든 키워드';
$GLOBALS['__l10n']['Best of me'] = '꼭 보세요';
$GLOBALS['__l10n']['Languages'] = '언어';
$GLOBALS['__l10n']['Categories'] = '분류';
$GLOBALS['__l10n']['Subcategories'] = '하위분류';
$GLOBALS['__l10n']['Archives'] = '글모둠';
$GLOBALS['__l10n']['Links'] = '링크';
$GLOBALS['__l10n']['Subscribe'] = '구독신청';
$GLOBALS['__l10n']['Entries feed'] = '글꼭지 타래소식';
$GLOBALS['__l10n']['Comments feed'] = '댓글 타래소식';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = '이 블로그의 댓글 타래소식 (Atom)';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '이 분류의 글꼭지들 타래소식 (Atom)';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '이 분류의 댓글들 타래소식 (Atom)';
$GLOBALS['__l10n']['This post\'s comments feed'] = '이 글꼭지에 대한 댓글 타래소식';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '이 글꼭지에 대한 댓글 타래소식 (Atom)';
$GLOBALS['__l10n']['Attachments'] = '첨부파일';
$GLOBALS['__l10n']['Permalink'] = '고유링크';
$GLOBALS['__l10n']['Comments'] = '댓글';
$GLOBALS['__l10n']['Your comment'] = '당신의 댓글';
$GLOBALS['__l10n']['Your comment has been published.'] = '당신의 댓글이 공개되었습니다.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '당신의 댓글이 전송되었고, 공개전 점검 대기 상태입니다.';
$GLOBALS['__l10n']['Add a comment'] = '댓글 달기';
$GLOBALS['__l10n']['Name or nickname'] = '이름 또는 별칭';
$GLOBALS['__l10n']['Email address'] = '이메일 주소';
$GLOBALS['__l10n']['Website'] = '웹사이트';
$GLOBALS['__l10n']['optional'] = '선택사항';
$GLOBALS['__l10n']['Comment'] = '댓글';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML코드는 텍스트로 보여지고, 웹주소는 자동으로 변환됩니다.';
$GLOBALS['__l10n']['Remember me on this blog'] = '이 블로그에서 나를 기억하도록하기';
$GLOBALS['__l10n']['preview'] = '미리보기';
$GLOBALS['__l10n']['send'] = '보내기';
$GLOBALS['__l10n']['They posted on the same topic'] = '이 글꼭지에 걸린 글들';
$GLOBALS['__l10n']['Trackback URL'] = '글걸기주소';
$GLOBALS['__l10n']['You must provide an author name'] = '글쓴이 이름을 쓰셔야 합니다.';
$GLOBALS['__l10n']['You must provide a comment'] = '댓글을 쓰셔야 합니다.';
$GLOBALS['__l10n']['Email address is not valid'] = '이메일 주소가 바르지 않습니다.';
$GLOBALS['__l10n']['Document not found'] = '문서가 없습니다.';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '찾는 문서는 존재하지 않는 문서입니다.';
$GLOBALS['__l10n']['Powered by %s'] = 'Powered by %s';
$GLOBALS['__l10n']['Subscribe to'] = '타래소식 받아보기';
$GLOBALS['__l10n']['What is an RSS feed?'] = '타래소식(RSS feed)이란?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '타래소식(RSS feed)이란 블로그 요약입니다. 타래소식은 블로그에 올라온 각종 글들의 내용이나 그 요약문을, 원문 링크와 기타 메타정보 등과 함께 목록형태로 제공합니다. 블로그에서 최근에 공개한 항목들은 당신이 선호하는 타래소식 구독기(RSS 리더)로 읽을 수 있습니다.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '다음 URL을 당신의 타래소식 구독기(RSS 리더)로 복사해 넣으세요:';
$GLOBALS['__l10n']['Password needed'] = '비밀번호가 필요합니다';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '이 영역에 접근하려면 비밀번호를 제시해야합니다.';
$GLOBALS['__l10n']['Password:'] = '비밀번호:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '올바른 이메일 주소를 쓰셔야합니다.';
$GLOBALS['__l10n']['Read'] = '읽기';

==> ko-2.7.zip: ko/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '글꼭지 내용으로';
$GLOBALS['__l10n']['To menu'] = '메뉴로';
$GLOBALS['__l10n']['To search'] = '찾기로';
$GLOBALS['__l10n']['By'] = '글쓴이 : ';
$GLOBALS['__l10n']['by'] = ' 글쓴이 : ';
$GLOBALS['__l10n']['on'] = ' 올린 때 : ';
$GLOBALS['__l10n']['On'] = '올린 때 : ';
$GLOBALS['__l10n']['Continue reading'] = '본문으로';
$GLOBALS['__l10n']['no comments'] = '댓글 없음';
$GLOBALS['__l10n']['one comment'] = '댓글 하나';
$GLOBALS['__l10n']['%d comments'] = '댓글 %d 개';
$GLOBALS['__l10n']['no trackbacks'] = '글걸이 없음';
$GLOBALS['__l10n']['one trackback'] = '글걸이 1 개';
$GLOBALS['__l10n']['%d trackbacks'] = '글걸이 %d 개';
$GLOBALS['__l10n']['no attachments'] = '첨부파일 없음';
$GLOBALS['__l10n']['one attachment'] = '첨부파일 한 개';
$GLOBALS['__l10n']['%d attachments'] = '첨부파일 %d 개';
$GLOBALS['__l10n']['previous entries'] = '이전 글꼭지';
$GLOBALS['__l10n']['page'] = '페이지';
$GLOBALS['__l10n']['of'] = '의';
$GLOBALS['__l10n']['next entries'] = '다음 글꼭지';
$GLOBALS['__l10n']['Search'] = '찾기';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '<em>%1$s</em>에 대한 찾기 결과가 없습니다.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '<em>%1$s</em>에 대한 찾기 결과 : <strong>%2$s</strong> 개 찾음.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '<em>%1$s</em>에 대한 찾기 결과 : <strong>%2$s</strong> 개 찾음.';
$GLOBALS['__l10n']['Home'] = '처음으로';
$GLOBALS['__l10n']['All keywords'] = '모든 키워드';
$GLOBALS['__l10n']['Best of me'] = '꼭 보세요';
$GLOBALS['__l10n']['Languages'] = '언어';
$GLOBALS['__l10n']['Categories'] = '분류';
$GLOBALS['__l10n']['Subcategories'] = '하위분류';
$GLOBALS['__l10n']['Archives'] = '글모둠';
$GLOBALS['__l10n']['Links'] = '링크';
$GLOBALS['__l10n']['Subscribe'] = '구독신청';
$GLOBALS['__l10n']['Entries feed'] = '글꼭지 타래소식';
$GLOBALS['__l10n']['Comments feed'] = '댓글 타래소식';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = '이 블로그의 댓글 타래소식 (Atom)';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '이 분류의 글꼭지들 타래소식 (Atom)';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '이 분류의 댓글들 타래소식 (Atom)';
$GLOBALS['__l10n']['This post\'s comments feed'] = '이 글꼭지에 대한 댓글 타래소식';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '이 글꼭지에 대한 댓글 타래소식 (Atom)';
$GLOBALS['__l10n']['Attachments'] = '첨부파일';
$GLOBALS['__l10n']['Permalink'] = '고유링크';
$GLOBALS['__l10n']['Comments'] = '댓글';
$GLOBALS['__l10n']['Your comment'] = '당신의 댓글';
$GLOBALS['__l10n']['Your comment has been published.'] = '당신의 댓글이 공개되었습니다.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '당신의 댓글이 전송되었고, 공개전 점검 대기 상태입니다.';
$GLOBALS['__l10n']['Add a comment'] = '댓글 달기';
$GLOBALS['__l10n']['Name or nickname'] = '이름 또는 별칭';
$GLOBALS['__l10n']['Email address'] = '이메일 주소';
$GLOBALS['__l10n']['Website'] = '웹사이트';
$GLOBALS['__l10n']['optional'] = '선택사항';
$GLOBALS['__l10n']['Comment'] = '댓글';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML코드는 텍스트로 보여지고, 웹주소는 자동으로 변환됩니다.';
$GLOBALS['__l10n']['Remember me on this blog'] = '이 블로그에서 나를 기억하도록하기';
$GLOBALS['__l10n']['preview'] = '미리보기';
$GLOBALS['__l10n']['send'] = '보내기';
$GLOBALS['__l10n']['They posted on the same topic'] = '이 글꼭지에 걸린 글들';
$GLOBALS['__l10n']['Trackback URL'] = '글걸기주소';
$GLOBALS['__l10n']['You must provide an author name'] = '글쓴이 이름을 쓰셔야 합니다.';
$GLOBALS['__l10n']['You must provide a comment'] = '댓글을 쓰셔야 합니다.';
$GLOBALS['__l10n']['Email address is not valid'] = '이메일 주소가 바르지 않습니다.';
$GLOBALS['__l10n']['Document not found'] = '문서가 없습니다.';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '찾는 문서는 존재하지 않는 문서입니다.';
$GLOBALS['__l10n']['Powered by %s'] = 'Powered by %s';
$GLOBALS['__l10n']['Subscribe to'] = '타래소식 받아보기';
$GLOBALS['__l10n']['What is an RSS feed?'] = '타래소식(RSS feed)이란?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '타래소식(RSS feed)이란 블로그 요약입니다. 타래소식은 블로그에 올라온 각종 글들의 내용이나 그 요약문을, 원문 링크와 기타 메타정보 등과 함께 목록형태로 제공합니다. 블로그에서 최근에 공개한 항목들은 당신이 선호하는 타래소식 구독기(RSS 리더)로 읽을 수 있습니다.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '다음 URL을 당신의 타래소식 구독기(RSS 리더)로 복사해 넣으세요:';
$GLOBALS['__l10n']['Password needed'] = '비밀번호가 필요합니다';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '이 영역에 접근하려면 비밀번호를 제시해야합니다.';
$GLOBALS['__l10n']['Password:'] = '비밀번호:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '올바른 이메일 주소를 쓰셔야합니다.';
$GLOBALS['__l10n']['Read'] = '읽기';
